import math
import random
import warnings
from datetime import date, time
from datetime import datetime
from pathlib import Path
from typing import Union, Dict, List, Generator

from otlmow_model.OtlmowModel.BaseClasses.DateField import DateField
from otlmow_model.OtlmowModel.BaseClasses.DateTimeField import DateTimeField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.OTLField import OTLField
from otlmow_model.OtlmowModel.BaseClasses.TimeField import TimeField
from otlmow_model.OtlmowModel.BaseClasses.URIField import URIField
from otlmow_model.OtlmowModel.BaseClasses.UnionTypeField import UnionTypeField
from otlmow_model.OtlmowModel.BaseClasses.UnionWaarden import UnionWaarden
from otlmow_model.OtlmowModel.Exceptions.AttributeDeprecationWarning import AttributeDeprecationWarning
from otlmow_model.OtlmowModel.Exceptions.ClassDeprecationWarning import ClassDeprecationWarning
from otlmow_model.OtlmowModel.Exceptions.MethodNotApplicableError import MethodNotApplicableError
from otlmow_model.OtlmowModel.Exceptions.NonStandardAttributeWarning import NonStandardAttributeWarning
from otlmow_model.OtlmowModel.Helpers.AssetCreator import dynamic_create_instance_from_uri, dynamic_create_type_from_uri


class OTLAttribuut:
    def __init__(self, naam='', label='', objectUri='', definition='', constraints='', usagenote='',
                 deprecated_version='', kardinaliteit_min='1', kardinaliteit_max='1', field=OTLField, readonly=False,
                 readonlyValue=None, owner=None):
        super().__init__()
        self.naam = naam
        self.label = label
        self.objectUri = objectUri
        self.definition = definition
        self.constraints = constraints
        self.usagenote = usagenote
        self.deprecated_version = deprecated_version
        self.readonly = readonly
        self.kardinaliteit_min = kardinaliteit_min
        self.kardinaliteit_max = kardinaliteit_max
        self._dotnotation = ''
        self.owner = owner
        self.readonlyValue = None
        self.waarde = None
        self.field = field

        if self.field.waardeObject:
            def add_empty_value():
                prev_value = self.waarde
                if kardinaliteit_max == '1':
                    if prev_value is None:
                        new_value_object = self.field.waardeObject()
                        new_value_object._parent = self
                        self.set_waarde(new_value_object)
                    else:
                        raise RuntimeError(
                            "This attribute does not have a cardinality other than 1, therefore you can only call this method once per instance")
                else:
                    if prev_value is None:
                        prev_value = []
                    new_value_object = self.field.waardeObject()
                    new_value_object._parent = self
                    prev_value.append(new_value_object)
                    self.set_waarde(prev_value)

            self.add_empty_value = add_empty_value

        if kardinaliteit_max != '1':
            def add_value(value):
                l = self.waarde
                if self.waarde is None:
                    l = []
                l.append(value)
                self.set_waarde(l)

            self.add_value = add_value

        if readonly:
            self.__dict__["waarde"] = readonlyValue

    def add_value(self, value):
        raise MethodNotApplicableError(
            "This attribute does not have a cardinality other than 1 so simply assign your value directly instead of "
            "using this method")

    def get_waarde(self):
        if self.field.waardeObject and self.waarde is None:
            self.add_empty_value()
        return self.waarde

    def add_empty_value(self):
        """Helper method for datatypes UnionType, ComplexType, KwantWrd and Dte to add the underlying waarde object"""
        if not self.field.waardeObject:
            raise MethodNotApplicableError(
                "In order to use this method this object must be one of these types: UnionType, ComplexType, KwantWrd, "
                "Dte")

    def default(self):
        if self.waarde is not dict and isinstance(self.waarde, list):
            value_list = []
            for item in self.waarde:
                if self.field.waardeObject is not None:
                    waarde_dict = vars(item)
                    value_dict = {}
                    for k, v in waarde_dict.items():
                        if v.default() is not None:
                            value_dict[k[1:]] = v.default()
                    if len(value_dict) != 0:
                        value_list.append(value_dict)
                else:
                    value_list.append(item)
            return value_list
        if self.field.waardeObject is not None:
            if self.field.waarde_shortcut_applicable:
                waarde_dict = vars(self.waarde)
                value_dict = {}
                for k, v in waarde_dict.items():
                    if v.default() is not None:
                        value_dict[k[1:]] = v.default()
                if len(value_dict) == 0:
                    return None
                return value_dict
            else:
                if self.waarde.waarde is not None:
                    if hasattr(self.waarde.waarde, 'default'):
                        return self.waarde.waarde.default()
                    else:
                        return self.waarde.waarde
                return None
        else:
            if isinstance(self.waarde, datetime):
                if self.waarde.hour == 0 and self.waarde.minute == 0 and self.waarde.second == 0:
                    return self.waarde.strftime("%Y-%m-%d")
                else:
                    return self.waarde.strftime("%Y-%m-%d %H:%M:%S")
            else:
                if hasattr(self.waarde, 'default'):
                    return self.waarde.default()
                else:
                    return self.waarde

    def _perform_cardinality_check(self, owner, value, kardinaliteit_max):
        kardinaliteit_min = int(self.kardinaliteit_min)
        if not isinstance(value, list):
            raise TypeError(f'expecting a list in {owner.__class__.__name__}.{self.naam}')
        elif isinstance(value, list) and isinstance(value, set):
            raise TypeError(f'expecting a non set type of list in {owner.__class__.__name__}.{self.naam}')
        elif 0 < len(value) < kardinaliteit_min:
            raise ValueError(
                f'expecting at least {kardinaliteit_min} element(s) in {owner.__class__.__name__}.{self.naam}')
        elif len(value) > kardinaliteit_max:
            raise ValueError(
                f'expecting at most {kardinaliteit_max} element(s) in {owner.__class__.__name__}.{self.naam}')

    def set_waarde(self, value, owner=None):
        self._perform_deprecation_check(self)

        if value is None:
            self.waarde = None
            return

        if self.kardinaliteit_max != '1':
            if self.kardinaliteit_max == '*':
                kardinaliteit_max = math.inf
            else:
                kardinaliteit_max = int(self.kardinaliteit_max)
            self._perform_cardinality_check(owner, value, kardinaliteit_max)
            converted_values = []
            for el_value in value:
                converted_value = self.field.convert_to_correct_type(el_value)
                if issubclass(self.field, KeuzelijstField):
                    converted_value = self.field.convert_to_invulwaarde(converted_value, self.field)

                field_validated = self.field.validate(converted_value, self)
                if not field_validated:
                    raise ValueError(
                        f'invalid value in list for {owner.__class__.__name__}.{self.naam}: {el_value} is not '
                        f'valid, must be valid for {self.field.naam}')
                converted_values.append(converted_value)
            self.waarde = converted_values
        else:
            if self.field.waardeObject is not None and isinstance(value, self.field.waardeObject):
                self.waarde = value
            else:
                converted_value = self.field.convert_to_correct_type(value)
                if issubclass(self.field, KeuzelijstField):
                    converted_value = self.field.convert_to_invulwaarde(converted_value, self.field)
                if self.field.validate(value=converted_value, attribuut=self):
                    self.waarde = converted_value
                else:
                    raise ValueError(
                        f'Could not assign the best effort converted value to {owner.__class__.__name__}.{self.naam}')

        # check if kwant Wrd inside a union type, if so, call clear_props
        if owner is not None and value is not None and hasattr(owner, 'field') and owner.field.waardeObject is not None:
            if owner.field.waarde_shortcut_applicable and not isinstance(
                    owner.field, UnionTypeField) and owner.owner is not None and isinstance(owner.owner, UnionWaarden):
                owner.owner.clear_other_props('_' + owner.naam)

    @staticmethod
    def _perform_deprecation_check(owner):
        if owner is not None:
            if owner.naam == 'waarde':
                owner = owner.owner._parent

            if hasattr(owner, 'deprecated_version'):
                if owner.deprecated_version != '':
                    if hasattr(owner, 'objectUri'):
                        warnings.warn(
                            message=f'{owner.objectUri} is deprecated since version {owner.deprecated_version}',
                            category=AttributeDeprecationWarning)
                    elif hasattr(owner, 'typeURI'):
                        warnings.warn(message=f'{owner.typeURI} is deprecated since version {owner.deprecated_version}',
                                      category=AttributeDeprecationWarning)
                    else:
                        warnings.warn(
                            message=f'used a class that is deprecated since version {owner.deprecated_version}',
                            category=AttributeDeprecationWarning)

    def __str__(self):
        s = (f'information about {self.naam}:\n'
             f'naam: {self.naam}\n'
             f'uri: {self.objectUri}\n'
             f'definition: {self.definition}\n'
             f'label: {self.label}\n'
             f'usagenote: {self.usagenote}\n'
             f'constraints: {self.constraints}\n'
             f'readonly: {self.readonly}\n'
             f'kardinaliteit_min: {self.kardinaliteit_min}\n'
             f'kardinaliteit_max: {self.kardinaliteit_max}\n'
             f'deprecated_version: {self.deprecated_version}\n')
        return s

    def fill_with_dummy_data(self):
        if self.readonly:
            return

        if self.field.waardeObject is None:
            if self.naam == 'geometry':
                first_geom_type = self.owner._geometry_types[0]
                if first_geom_type == 'POINT Z':
                    self.set_waarde('POINT Z (200000 200000 0)')
                elif first_geom_type == 'LINESTRING Z':
                    self.set_waarde('LINESTRING Z (200000 200000 0, 200001 200001 1)')
                elif first_geom_type == 'POLYGON Z':
                    self.set_waarde('POLYGON Z ((200000 200000 0, 200001 200001 1, 200002 200002 2))')
                return
            else:
                data = self.field.create_dummy_data()
                if self.kardinaliteit_max != '1':
                    self.set_waarde([data])
                else:
                    self.set_waarde(data)
                return

        new_value_object = self.field.waardeObject()
        new_value_object._parent = self

        if isinstance(new_value_object, UnionWaarden):
            selected_attr = random.choice(list(new_value_object))
            selected_attr.fill_with_dummy_data()
        else:
            for a in new_value_object:
                a.fill_with_dummy_data()

        if self.kardinaliteit_max != '1':
            self.set_waarde([new_value_object])
        else:
            self.set_waarde(new_value_object)


class OTLObject(object):
    typeURI: str = None
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __setattr__(self, name, value):
        if name != 'typeURI':
            super(OTLObject, self).__setattr__(name, value)
        else:
            if hasattr(self, 'typeURI') and (value is not None or self.typeURI is not None):
                raise ValueError("The typeURI is an OSLOAttribute that indicates the class of the instance. "
                                 "Within a class this value is predefined and cannot be changed.")
            else:
                if URIField.validate(value, OTLAttribuut(naam='typeURI')):
                    self.__dict__['value'] = value
                else:
                    raise ValueError(f'{value} is not a valid value for typeURI.')

    def __init__(self):
        super().__init__()

        if hasattr(self, 'deprecated_version'):
            if self.deprecated_version is not None:
                try:
                    warnings.warn(message=f'{self.typeURI} is deprecated since version {self.deprecated_version}',
                                  category=ClassDeprecationWarning)
                except KeyError:
                    warnings.warn(
                        message=f'used a class ({self.__class__.__name__}) that is deprecated since version {self.deprecated_version}',
                        category=ClassDeprecationWarning)

    def create_dict_from_asset(self, waarde_shortcut: bool = False, rdf: bool = False, datetime_as_string: bool = False,
                               suppress_warnings_non_standardised_attributes: bool = False) -> Dict:
        """Converts this asset into a dictionary representation"""
        return create_dict_from_asset(
            otl_object=self, waarde_shortcut=waarde_shortcut, rdf=rdf, datetime_as_string=datetime_as_string,
            suppress_warnings_non_standardised_attributes=suppress_warnings_non_standardised_attributes)

    def fill_with_dummy_data(self):
        for attr in self:
            if attr is not None:
                attr.fill_with_dummy_data()

    def __repr__(self):
        return build_string_version(asset=self)

    def __iter__(self) -> Generator[OTLAttribuut, None, None]:
        yield from sorted(filter(lambda v: isinstance(v, OTLAttribuut), (vars(self).values())), key=lambda x: x.naam)

    def __eq__(self, other):
        return create_dict_from_asset(self) == create_dict_from_asset(other)

    def is_instance_of(self, otl_type: type, dynamic_created: bool = False, model_directory: Path = None):
        if dynamic_created:
            if model_directory is None:
                current_file_path = Path(__file__)
                model_directory = current_file_path.parent.parent.parent
            try:
                otl_type_typeURI = getattr(otl_type, 'typeURI')
            except AttributeError:
                return False
            dynamic_created_type = dynamic_create_type_from_uri(otl_type_typeURI, model_directory=model_directory)
            return isinstance(self, dynamic_created_type)

        check = isinstance(self, otl_type)
        if check:
            return True

        try:
            otl_type_typeURI = getattr(otl_type, 'typeURI')
        except AttributeError:
            return False

        t = type(self)
        if t.typeURI == otl_type_typeURI:
            return True
        return issubclass(self.__class__, otl_type)

    @classmethod
    def from_dict(cls, input_dict: Dict, model_directory: Path = None, rdf: bool = False,
                  datetime_as_string: bool = False, waarde_shortcut: bool = False) -> object:
        """Alternative constructor. Allows the instantiation of an object using a dictionary. Either start from the
        appropriate class or add a typeURI entry to the dictionary to get an instance of that type.

        :param input_dict: input dictionary, containing key value pairs for the attributes of the instance
        :type: dict
        :param model_directory: directory where the model is located, defaults to otlmow_model's own model
        :type: str
        :param rdf: whether to use uri's as keys instead of the names, defaults to False
        :type: bool
        :param waarde_shortcut: whether to use the waarde shortcut when processing the dictionary, defaults to False
        :type: bool
        :param datetime_as_string: whether to convert dates, times and datetimes to strings, defaults to False
        :type: bool
        :return: returns an instance where the values of the attributes matches the given dictionary
        :rtype: OTLObject"""
        if not rdf and 'typeURI' in input_dict:
            type_uri = input_dict['typeURI']
        elif rdf and 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#AIMObject.typeURI' in input_dict:
            type_uri = input_dict['https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#AIMObject.typeURI']
        else:
            type_uri = cls.typeURI

        if type_uri is None:
            raise ValueError(
                'typeURI is None. Add a valid typeURI to the input dictionary or change the class you are using "from_dict" from.')

        if model_directory is None:
            current_file_path = Path(__file__)
            model_directory = current_file_path.parent.parent.parent

        try:
            o = dynamic_create_instance_from_uri(type_uri, model_directory=model_directory)
        except TypeError:
            raise ValueError(
                'typeURI is invalid. Add a valid typeURI to the input dictionary or change the class you are using "from_dict" from.')

        for k, v in input_dict.items():
            if k == 'typeURI' or k == 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#AIMObject.typeURI':
                continue
            set_value_by_dictitem(o, k, v, waarde_shortcut=waarde_shortcut, rdf=rdf,
                                  datetime_as_string=datetime_as_string)
        return o


def create_dict_from_asset(otl_object: OTLObject, waarde_shortcut=False, rdf: bool = False,
                           datetime_as_string: bool = False,
                           suppress_warnings_non_standardised_attributes: bool = False) -> Dict:
    """Creates a dictionary from an OTLObject with key value pairs for attributes and their values. Saves the type of the object in typeURI (or @type for the RDF dict)

    :param otl_object: input object to be transformed
    :type: OTLObject
    :param waarde_shortcut: whether to use the waarde shortcut when processing the dictionary, defaults to False
    :type: bool
    :param rdf: whether to generate a dictionary where the key's are the URI's of the attributes rather than the names, defaults to False
    :type: bool
    :param datetime_as_string: whether to convert dates, times and datetimes to strings, defaults to False
    :type: bool
    :param suppress_warnings_non_standardised_attributes: whether to suppress the warning that are raised because the object has attributes that aren't standardised
    :type: bool

    :return: returns an instance where the values of the attributes matches the given dictionary
    :rtype: OTLObject"""
    if rdf:
        d = _recursive_create_rdf_dict_from_asset(
            asset=otl_object, waarde_shortcut=waarde_shortcut, datetime_as_string=datetime_as_string,
            suppress_warnings_non_standardised_attributes=suppress_warnings_non_standardised_attributes)
    else:
        d = _recursive_create_dict_from_asset(
            asset=otl_object, waarde_shortcut=waarde_shortcut, datetime_as_string=datetime_as_string,
            suppress_warnings_non_standardised_attributes=suppress_warnings_non_standardised_attributes)

    if d is None:
        d = {}
    if rdf:
        d['@type'] = otl_object.typeURI
    else:
        d['typeURI'] = otl_object.typeURI
    return d


def _recursive_create_dict_from_asset(
        asset: Union[OTLObject, OTLAttribuut, list, dict], waarde_shortcut: bool = False,
        datetime_as_string: bool=False, suppress_warnings_non_standardised_attributes: bool = False
) -> Union[Dict, List[Dict]]:
    if isinstance(asset, list) and not isinstance(asset, dict):
        l = []
        for item in asset:
            dict_item = _recursive_create_dict_from_asset(
                asset=item, waarde_shortcut=waarde_shortcut, datetime_as_string=datetime_as_string,
                suppress_warnings_non_standardised_attributes=suppress_warnings_non_standardised_attributes)
            if dict_item is not None:
                l.append(dict_item)
        return l
    else:
        d = {}
        for attr_key, attr in vars(asset).items():
            if attr_key == '_parent' or attr_key == '_valid_relations':
                continue
            if isinstance(attr, OTLAttribuut):
                if attr.waarde is None:
                    continue
                if attr.waarde == []:
                    d[attr.naam] = []
                    continue

                if attr.field.waardeObject is not None:  # complex
                    if waarde_shortcut and attr.field.waarde_shortcut_applicable:
                        if isinstance(attr.waarde, list):
                            dict_item = [item.waarde for item in attr.waarde]
                            if len(dict_item) > 0:
                                d[attr.naam] = dict_item
                        else:
                            dict_item = attr.waarde.waarde
                            if dict_item is not None:
                                d[attr.naam] = dict_item
                    else:
                        dict_item = _recursive_create_dict_from_asset(
                            asset=attr.waarde, waarde_shortcut=waarde_shortcut, datetime_as_string=datetime_as_string,
                            suppress_warnings_non_standardised_attributes=suppress_warnings_non_standardised_attributes)
                        if dict_item is not None:
                            d[attr.naam] = dict_item
                else:
                    if datetime_as_string:
                        if attr.field == TimeField:
                            d[attr.naam] = time.strftime(attr.waarde, "%H:%M:%S")
                        elif attr.field == DateField:
                            d[attr.naam] = date.strftime(attr.waarde, "%Y-%m-%d")
                        elif attr.field == DateTimeField:
                            d[attr.naam] = datetime.strftime(attr.waarde, "%Y-%m-%d %H:%M:%S")
                        else:
                            d[attr.naam] = attr.waarde
                    else:
                        d[attr.naam] = attr.waarde
            else:
                if not attr_key.startswith('_'):
                    if not suppress_warnings_non_standardised_attributes:
                        warnings.warn(
                            message=f'{attr_key} is a non standardized attribute of {asset.__class__.__name__}. '
                                    f'The attribute will be added on the instance', stacklevel=2,
                            category=NonStandardAttributeWarning)
                    d[attr_key] = attr

        if len(d.items()) > 0:
            return d


def _recursive_create_rdf_dict_from_asset(
        asset: Union[OTLObject, OTLAttribuut, list, dict], waarde_shortcut: bool = False,
        datetime_as_string: bool = False,
        suppress_warnings_non_standardised_attributes: bool = False) -> Union[Dict, List[Dict]]:
    if isinstance(asset, list) and not isinstance(asset, dict):
        l = []
        for item in asset:
            dict_item = _recursive_create_rdf_dict_from_asset(
                asset=item, waarde_shortcut=waarde_shortcut, datetime_as_string=datetime_as_string,
                suppress_warnings_non_standardised_attributes=suppress_warnings_non_standardised_attributes)
            if dict_item is not None:
                l.append(dict_item)
        if len(l) > 0:
            return l
    else:
        d = {}
        for attr_key, attr in vars(asset).items():
            if attr_key == '_parent' or attr_key == '_valid_relations':
                continue
            if isinstance(attr, OTLAttribuut):
                if attr.waarde is None or attr.waarde == []:
                    continue

                if attr.field.waardeObject is not None:  # complex
                    if waarde_shortcut and attr.field.waarde_shortcut_applicable:
                        if isinstance(attr.waarde, list):
                            dict_item = [item.waarde for item in attr.waarde]
                            if len(dict_item) > 0:
                                d[attr.objectUri] = dict_item
                        else:
                            dict_item = attr.waarde.waarde
                            if dict_item is not None:
                                d[attr.objectUri] = dict_item
                    else:
                        dict_item = _recursive_create_rdf_dict_from_asset(
                            asset=attr.waarde, waarde_shortcut=waarde_shortcut, datetime_as_string=datetime_as_string,
                            suppress_warnings_non_standardised_attributes=suppress_warnings_non_standardised_attributes)
                        if dict_item is not None:
                            d[attr.objectUri] = dict_item
                else:
                    if datetime_as_string and attr.field == TimeField:
                            d[attr.objectUri] = time.strftime(attr.waarde, "%H:%M:%S")
                    elif datetime_as_string and attr.field == DateField:
                        d[attr.objectUri] = date.strftime(attr.waarde, "%Y-%m-%d")
                    elif datetime_as_string and attr.field == DateTimeField:
                        d[attr.objectUri] = datetime.strftime(attr.waarde, "%Y-%m-%d %H:%M:%S")
                    elif issubclass(attr.field, KeuzelijstField):
                        if isinstance(attr.waarde, list):
                            if attr.waarde == [None]:
                                d[attr.objectUri] = []
                            else:
                                d[attr.objectUri] = [attr.field.options[list_item].objectUri for list_item in
                                                     attr.waarde]
                        else:
                            d[attr.objectUri] = attr.field.options[attr.waarde].objectUri
                    else:
                        d[attr.objectUri] = attr.waarde
            else:
                if not attr_key.startswith('_'):
                    if not suppress_warnings_non_standardised_attributes:
                        warnings.warn(
                            message=f'{attr_key} is a non standardized attribute of {asset.__class__.__name__}. '
                                    f'The attribute will be added on the instance',
                            category=NonStandardAttributeWarning)
                    d[attr_key] = attr

        if len(d.items()) > 0:
            return d


def clean_dict(d) -> Union[Dict, None]:
    """Recursively remove None values and empty dicts from input dict"""
    if d is None:
        return None
    for k in list(d):
        v = d[k]
        if isinstance(v, dict):
            clean_dict(v)
            if len(v.items()) == 0:
                del d[k]
        if v is None:
            del d[k]
    return d


def build_string_version(asset, indent: int = 4) -> str:
    if indent < 4:
        indent = 4
    d = create_dict_from_asset(asset, suppress_warnings_non_standardised_attributes=True)
    string_version = '\n'.join(_make_string_version_from_dict(d, level=1, indent=indent, prefix='    '))
    if string_version != '':
        string_version = '\n' + string_version
    return f'<{asset.__class__.__name__}> object\n{(" " * indent)}typeURI : {asset.typeURI}' + string_version


def _make_string_version_from_dict(d, level: int = 0, indent: int = 4, list_index: int = -1, prefix: str = '') -> List:
    lines = []

    if list_index != -1:
        index_string = f'[{list_index}]'
        index_string += ' ' * (indent - len(index_string))
        prefix += index_string

    for key in sorted(d):
        if key == 'typeURI':
            continue
        value = d[key]
        if isinstance(value, dict):
            lines.append(prefix + f'{key} :')
            lines.extend(_make_string_version_from_dict(value, level=level + 1, indent=indent,
                                                        prefix=prefix + ' ' * indent * level))
        elif isinstance(value, list):
            lines.append(prefix + f'{key} :')
            for index, item in enumerate(value):
                if index == 10:
                    if len(value) == 11:
                        lines.append(prefix + '...(1 more item)')
                    else:
                        lines.append(prefix + f'...({len(value) - 10} more items)')
                    break
                if isinstance(item, dict):
                    lines.extend(_make_string_version_from_dict(item, level=level, indent=indent, list_index=index,
                                                                prefix=prefix))
                else:
                    index_string = f'[{index}]'
                    index_string += ' ' * (indent - len(index_string))
                    lines.append(prefix + index_string + f'{item}')
        else:
            lines.append(prefix + f'{key} : {value}')
    return lines


def get_attribute_by_uri(instance_or_attribute, key: str) -> Union[OTLAttribuut, None]:
    return next((v for v in instance_or_attribute if v.objectUri == key), None)


def get_attribute_by_name(instance_or_attribute, key: str) -> Union[OTLAttribuut, None]:
    return getattr(instance_or_attribute, '_' + key, None)


# dict encoder = asset object to dict
# dict decoder = dict to asset object

def set_value_by_dictitem(instance_or_attribute: Union[OTLObject, OTLAttribuut], key: str, value,
                          waarde_shortcut: bool = False, rdf: bool = False, datetime_as_string: bool = False):
    if instance_or_attribute is None:
        raise ValueError('instance_or_attribute cannot be None')
    if key is None or key == '':
        raise ValueError('key cannot be empty')

    if rdf:
        attribute_to_set = get_attribute_by_uri(instance_or_attribute, key)
    else:
        attribute_to_set = get_attribute_by_name(instance_or_attribute, key)

    if attribute_to_set is None:
        warnings.warn(
            message=f'Attribute with name "{key}" can not be found on the given instance or attribute. Assume this is '
                    f'a non standardized attribute. Setting the attribute with setattr',
            category=NonStandardAttributeWarning)
        setattr(instance_or_attribute, key, value)
        return

    if attribute_to_set.field.waardeObject is not None:  # complex / union / KwantWrd / dte
        if isinstance(value, list):
            for index, list_item in enumerate(value):
                if attribute_to_set.waarde is None or len(attribute_to_set.waarde) <= index:
                    attribute_to_set.add_empty_value()

                if attribute_to_set.field.waarde_shortcut_applicable and waarde_shortcut:  # dte / kwantWrd
                    attribute_to_set.waarde[index]._waarde.set_waarde(list_item)
                else:  # complex / union
                    for k, v in list_item.items():
                        set_value_by_dictitem(attribute_to_set.waarde[index], k, v, waarde_shortcut, rdf=rdf,
                                              datetime_as_string=datetime_as_string)

        elif isinstance(value, dict):  # only complex / union possible
            if attribute_to_set.waarde is None:
                attribute_to_set.add_empty_value()

            if attribute_to_set.kardinaliteit_max != '1':
                for k, v in value.items():
                    set_value_by_dictitem(attribute_to_set.waarde[0], k, v, waarde_shortcut, rdf=rdf,
                                          datetime_as_string=datetime_as_string)
            else:
                for k, v in value.items():
                    set_value_by_dictitem(attribute_to_set.waarde, k, v, waarde_shortcut, rdf=rdf,
                                          datetime_as_string=datetime_as_string)
        else:  # must be a dte / kwantWrd
            if attribute_to_set.waarde is None:
                attribute_to_set.add_empty_value()

            if datetime_as_string and attribute_to_set.waarde._waarde.field in [TimeField, DateField, DateTimeField]:
                value = attribute_to_set.waarde._waarde.field.convert_to_correct_type(value=value, log_warnings=False)
            attribute_to_set.waarde._waarde.set_waarde(value)
    else:
        if datetime_as_string and attribute_to_set.field in [TimeField, DateField, DateTimeField]:
           value = attribute_to_set.field.convert_to_correct_type(value=value, log_warnings=False)
        attribute_to_set.set_waarde(value)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.AanhorigheidKoker import AanhorigheidKoker
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlMateriaalTrap import KlMateriaalTrap
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Trap(AanhorigheidKoker, AIMNaamObject, VlakGeometrie):
    """Een constructie die een verbinding vormt tussen twee op verschillend niveau gelegen vlakken. Bestaande uit armen en bordessen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Trap'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kokerruimte')

        self._lengte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='lengte',
                                    label='lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Trap.lengte',
                                    definition='De lengte van de trap in de lopende meters die trap aflegt.',
                                    owner=self)

        self._materiaal = OTLAttribuut(field=KlMateriaalTrap,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Trap.materiaal',
                                       definition='Het materiaal waaruit de trap is vervaardigd.',
                                       owner=self)

        self._niveauverschil = OTLAttribuut(field=KwantWrdInMeter,
                                            naam='niveauverschil',
                                            label='niveauverschil',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Trap.niveauverschil',
                                            definition='Verschil in hoogte tussen 2 niveaus.',
                                            owner=self)

    @property
    def lengte(self) -> KwantWrdInMeterWaarden:
        """De lengte van de trap in de lopende meters die trap aflegt."""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """Het materiaal waaruit de trap is vervaardigd."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)

    @property
    def niveauverschil(self) -> KwantWrdInMeterWaarden:
        """Verschil in hoogte tussen 2 niveaus."""
        return self._niveauverschil.get_waarde()

    @niveauverschil.setter
    def niveauverschil(self, value):
        self._niveauverschil.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.ImplementatieElement.DirectioneleRelatie import DirectioneleRelatie


# Generated with OTLClassCreator. To modify: extend, do not edit
class VoedtAangestuurd(DirectioneleRelatie):
    """Deze relatie wordt enkel gelegd naar objecttypes die typisch een groot vermogen vereisen en onder spanning komen nadat het voedend element aangestuurd is om die spanning door te sturen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoedtAangestuurd'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()



# coding=utf-8
from datetime import datetime
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Proef import Proef
from otlmow_model.OtlmowModel.BaseClasses.DateTimeField import DateTimeField
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from otlmow_model.OtlmowModel.BaseClasses.FloatOrDecimalField import FloatOrDecimalField
from ...Datatypes.KlBoomConditiebeoordeling import KlBoomConditiebeoordeling
from ...Datatypes.KlBoomConditiewaarde import KlBoomConditiewaarde
from ...Datatypes.KlBoomConflicten import KlBoomConflicten
from ...Datatypes.KlBoomGebreken import KlBoomGebreken
from ...Datatypes.KlBoomOnderhoudstoestand import KlBoomOnderhoudstoestand
from ...Datatypes.KlBoomPlantwijzewaarde import KlBoomPlantwijzewaarde
from ...Datatypes.KlBoomStandplaatswaarde import KlBoomStandplaatswaarde
from ...Datatypes.KlBoomtoestandMeerwaardefactor import KlBoomtoestandMeerwaardefactor
from ...Datatypes.KwantWrdInCentimeter import KwantWrdInCentimeter, KwantWrdInCentimeterWaarden
from ...Datatypes.KwantWrdInEuro import KwantWrdInEuro, KwantWrdInEuroWaarden
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class ProefBoomtoestand(Proef, PuntGeometrie, LijnGeometrie, VlakGeometrie):
    """De toestand met waarnemingen per inspectie van een boom."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Boom')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#OpgaandeBoom', deprecated='2.0.0')

        self._basiswaarde = OTLAttribuut(field=KwantWrdInEuro,
                                         naam='basiswaarde',
                                         label='rapportage onderzoek',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.basiswaarde',
                                         definition='Het schriftelijk verslag dat na onderzoek of visuele controle wordt opgemaakt.',
                                         owner=self)

        self._conditiebeoordeling = OTLAttribuut(field=KlBoomConditiebeoordeling,
                                                 naam='conditiebeoordeling',
                                                 label='conditiebeoordeling',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.conditiebeoordeling',
                                                 definition='De conditie beoordeeld volgens de kronenstructuur van Dr. A. Roloff, gelet op de scheutlengte ontwikkeling en vorming van dood hout.',
                                                 owner=self)

        self._conditiewaarde = OTLAttribuut(field=KlBoomConditiewaarde,
                                            naam='conditiewaarde',
                                            label='conditiewaarde',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.conditiewaarde',
                                            definition='Een coëfficiënt die iets vertelt over de gezondheidstoestand (vitaliteit, conditie) en de levensverwachting van een boom.',
                                            owner=self)

        self._conflicten = OTLAttribuut(field=KlBoomConflicten,
                                        naam='conflicten',
                                        label='conflicten',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.conflicten',
                                        definition='Mogelijke standplaatsconflicten die de condities of structuur van de boom negatief kunnen beïnvloeden.',
                                        owner=self)

        self._gebreken = OTLAttribuut(field=KlBoomGebreken,
                                      naam='gebreken',
                                      label='gebreken',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.gebreken',
                                      kardinaliteit_max='*',
                                      definition='Een visueel defect aan een boom wat dient gemonitord te worden.',
                                      owner=self)

        self._kroonDiameter = OTLAttribuut(field=KwantWrdInMeter,
                                           naam='kroonDiameter',
                                           label='kroondiameter',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.kroonDiameter',
                                           definition='Diameter van de kroonprojectie in meter.',
                                           owner=self)

        self._krooninspectie = OTLAttribuut(field=DtcDocument,
                                            naam='krooninspectie',
                                            label='krooninspectie',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.krooninspectie',
                                            definition='Controle van gebrekssymptomen in de kroon.',
                                            owner=self)

        self._meerwaarde = OTLAttribuut(field=KlBoomtoestandMeerwaardefactor,
                                        naam='meerwaarde',
                                        label='meerwaarde',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.meerwaarde',
                                        definition='Mogelijkheid om de boom een waarde toe te kennen op basis van hun uitzonderlijke ecologische of erfgoedwaarde .',
                                        owner=self)

        self._onderhoudstoestand = OTLAttribuut(field=KlBoomOnderhoudstoestand,
                                                naam='onderhoudstoestand',
                                                label='onderhoudstoestand',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.onderhoudstoestand',
                                                definition='De toestand van een boom die de eventuele snoeiachterstand aangeeft.',
                                                owner=self)

        self._onderzoekVisueleBoomcontrole = OTLAttribuut(field=DtcDocument,
                                                          naam='onderzoekVisueleBoomcontrole',
                                                          label='Onderzoek visuele boomcontrole',
                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.onderzoekVisueleBoomcontrole',
                                                          definition='Visueel bepalen van de veiligheid en conditie van een boom.',
                                                          owner=self)

        self._plantwijzewaarde = OTLAttribuut(field=KlBoomPlantwijzewaarde,
                                              naam='plantwijzewaarde',
                                              label='plantwijzewaarde',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.plantwijzewaarde',
                                              definition='Een factor die de ontwikkeling van het uiterlijk (de habitus) van een boom relateert met de manier waarop hij geplant wordt.',
                                              owner=self)

        self._rapportageOnderzoek = OTLAttribuut(field=DtcDocument,
                                                 naam='rapportageOnderzoek',
                                                 label='rapportage onderzoek',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.rapportageOnderzoek',
                                                 definition='Het schriftelijk verslag dat na onderzoek of visuele controle wordt opgemaakt.',
                                                 owner=self)

        self._soortwaarde = OTLAttribuut(field=FloatOrDecimalField,
                                         naam='soortwaarde',
                                         label='soortwaarde',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.soortwaarde',
                                         definition='Geeft voor een bepaalde boomsoort of -variëteit de verhouding weer tussen de prijs per cm² van die soort en de eenheidsprijs.',
                                         owner=self)

        self._stamomtrek = OTLAttribuut(field=KwantWrdInCentimeter,
                                        naam='stamomtrek',
                                        label='stamomtrek',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.stamomtrek',
                                        definition='Omtrek van de stam van de boom in cm, gemeten op 1 meter boven de grond.',
                                        owner=self)

        self._standplaatswaarde = OTLAttribuut(field=KlBoomStandplaatswaarde,
                                               naam='standplaatswaarde',
                                               label='standplaatswaarde',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.standplaatswaarde',
                                               definition='De waarde van de boom afhankelijk van de bebouwingsdichtheid en de aanplantingsmogelijkheden rondom en voor de boom.',
                                               owner=self)

        self._tijdstempelBoomtoestand = OTLAttribuut(field=DateTimeField,
                                                     naam='tijdstempelBoomtoestand',
                                                     label='tijdstempel boomtoestand',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.tijdstempelBoomtoestand',
                                                     definition='Datum van laatste snoeibeurt.',
                                                     owner=self)

        self._uitgebreidPlaatsonderzoek = OTLAttribuut(field=DtcDocument,
                                                       naam='uitgebreidPlaatsonderzoek',
                                                       label='uitgebreid plaatsonderzoek',
                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.uitgebreidPlaatsonderzoek',
                                                       definition='Grondige beoordeling van de textuur en structuur van de bodem, met als doel een voorstel tot conditieverbeterende maatregelen.',
                                                       owner=self)

        self._wortelonderzoek = OTLAttribuut(field=DtcDocument,
                                             naam='wortelonderzoek',
                                             label='Wortelonderzoek',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefBoomtoestand.wortelonderzoek',
                                             definition='Bepalen van de kwaliteit van de wortels (bv. aantasting door schimmels) of het bepalen van de reikwijdte van de wortels (bv. om een wortelbeschermingszone op te zetten in de buurt van werken van de bomen).',
                                             owner=self)

    @property
    def basiswaarde(self) -> KwantWrdInEuroWaarden:
        """Het schriftelijk verslag dat na onderzoek of visuele controle wordt opgemaakt."""
        return self._basiswaarde.get_waarde()

    @basiswaarde.setter
    def basiswaarde(self, value):
        self._basiswaarde.set_waarde(value, owner=self)

    @property
    def conditiebeoordeling(self) -> str:
        """De conditie beoordeeld volgens de kronenstructuur van Dr. A. Roloff, gelet op de scheutlengte ontwikkeling en vorming van dood hout."""
        return self._conditiebeoordeling.get_waarde()

    @conditiebeoordeling.setter
    def conditiebeoordeling(self, value):
        self._conditiebeoordeling.set_waarde(value, owner=self)

    @property
    def conditiewaarde(self) -> str:
        """Een coëfficiënt die iets vertelt over de gezondheidstoestand (vitaliteit, conditie) en de levensverwachting van een boom."""
        return self._conditiewaarde.get_waarde()

    @conditiewaarde.setter
    def conditiewaarde(self, value):
        self._conditiewaarde.set_waarde(value, owner=self)

    @property
    def conflicten(self) -> str:
        """Mogelijke standplaatsconflicten die de condities of structuur van de boom negatief kunnen beïnvloeden."""
        return self._conflicten.get_waarde()

    @conflicten.setter
    def conflicten(self, value):
        self._conflicten.set_waarde(value, owner=self)

    @property
    def gebreken(self) -> List[str]:
        """Een visueel defect aan een boom wat dient gemonitord te worden."""
        return self._gebreken.get_waarde()

    @gebreken.setter
    def gebreken(self, value):
        self._gebreken.set_waarde(value, owner=self)

    @property
    def kroonDiameter(self) -> KwantWrdInMeterWaarden:
        """Diameter van de kroonprojectie in meter."""
        return self._kroonDiameter.get_waarde()

    @kroonDiameter.setter
    def kroonDiameter(self, value):
        self._kroonDiameter.set_waarde(value, owner=self)

    @property
    def krooninspectie(self) -> DtcDocumentWaarden:
        """Controle van gebrekssymptomen in de kroon."""
        return self._krooninspectie.get_waarde()

    @krooninspectie.setter
    def krooninspectie(self, value):
        self._krooninspectie.set_waarde(value, owner=self)

    @property
    def meerwaarde(self) -> str:
        """Mogelijkheid om de boom een waarde toe te kennen op basis van hun uitzonderlijke ecologische of erfgoedwaarde ."""
        return self._meerwaarde.get_waarde()

    @meerwaarde.setter
    def meerwaarde(self, value):
        self._meerwaarde.set_waarde(value, owner=self)

    @property
    def onderhoudstoestand(self) -> str:
        """De toestand van een boom die de eventuele snoeiachterstand aangeeft."""
        return self._onderhoudstoestand.get_waarde()

    @onderhoudstoestand.setter
    def onderhoudstoestand(self, value):
        self._onderhoudstoestand.set_waarde(value, owner=self)

    @property
    def onderzoekVisueleBoomcontrole(self) -> DtcDocumentWaarden:
        """Visueel bepalen van de veiligheid en conditie van een boom."""
        return self._onderzoekVisueleBoomcontrole.get_waarde()

    @onderzoekVisueleBoomcontrole.setter
    def onderzoekVisueleBoomcontrole(self, value):
        self._onderzoekVisueleBoomcontrole.set_waarde(value, owner=self)

    @property
    def plantwijzewaarde(self) -> str:
        """Een factor die de ontwikkeling van het uiterlijk (de habitus) van een boom relateert met de manier waarop hij geplant wordt."""
        return self._plantwijzewaarde.get_waarde()

    @plantwijzewaarde.setter
    def plantwijzewaarde(self, value):
        self._plantwijzewaarde.set_waarde(value, owner=self)

    @property
    def rapportageOnderzoek(self) -> DtcDocumentWaarden:
        """Het schriftelijk verslag dat na onderzoek of visuele controle wordt opgemaakt."""
        return self._rapportageOnderzoek.get_waarde()

    @rapportageOnderzoek.setter
    def rapportageOnderzoek(self, value):
        self._rapportageOnderzoek.set_waarde(value, owner=self)

    @property
    def soortwaarde(self) -> float:
        """Geeft voor een bepaalde boomsoort of -variëteit de verhouding weer tussen de prijs per cm² van die soort en de eenheidsprijs."""
        return self._soortwaarde.get_waarde()

    @soortwaarde.setter
    def soortwaarde(self, value):
        self._soortwaarde.set_waarde(value, owner=self)

    @property
    def stamomtrek(self) -> KwantWrdInCentimeterWaarden:
        """Omtrek van de stam van de boom in cm, gemeten op 1 meter boven de grond."""
        return self._stamomtrek.get_waarde()

    @stamomtrek.setter
    def stamomtrek(self, value):
        self._stamomtrek.set_waarde(value, owner=self)

    @property
    def standplaatswaarde(self) -> str:
        """De waarde van de boom afhankelijk van de bebouwingsdichtheid en de aanplantingsmogelijkheden rondom en voor de boom."""
        return self._standplaatswaarde.get_waarde()

    @standplaatswaarde.setter
    def standplaatswaarde(self, value):
        self._standplaatswaarde.set_waarde(value, owner=self)

    @property
    def tijdstempelBoomtoestand(self) -> datetime:
        """Datum van laatste snoeibeurt."""
        return self._tijdstempelBoomtoestand.get_waarde()

    @tijdstempelBoomtoestand.setter
    def tijdstempelBoomtoestand(self, value):
        self._tijdstempelBoomtoestand.set_waarde(value, owner=self)

    @property
    def uitgebreidPlaatsonderzoek(self) -> DtcDocumentWaarden:
        """Grondige beoordeling van de textuur en structuur van de bodem, met als doel een voorstel tot conditieverbeterende maatregelen."""
        return self._uitgebreidPlaatsonderzoek.get_waarde()

    @uitgebreidPlaatsonderzoek.setter
    def uitgebreidPlaatsonderzoek(self, value):
        self._uitgebreidPlaatsonderzoek.set_waarde(value, owner=self)

    @property
    def wortelonderzoek(self) -> DtcDocumentWaarden:
        """Bepalen van de kwaliteit van de wortels (bv. aantasting door schimmels) of het bepalen van de reikwijdte van de wortels (bv. om een wortelbeschermingszone op te zetten in de buurt van werken van de bomen)."""
        return self._wortelonderzoek.get_waarde()

    @wortelonderzoek.setter
    def wortelonderzoek(self, value):
        self._wortelonderzoek.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBouwputType(KeuzelijstField):
    """Het type van bouwput."""
    naam = 'KlBouwputType'
    label = 'Bouwput type.'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBouwputType'
    definition = 'Het type van bouwput.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBouwputType'
    options = {
        'bouwput': KeuzelijstWaarde(invulwaarde='bouwput',
                                    label='bouwput',
                                    status='ingebruik',
                                    definitie='bouwput',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBouwputType/bouwput'),
        'intredeput': KeuzelijstWaarde(invulwaarde='intredeput',
                                       label='intredeput',
                                       status='ingebruik',
                                       definitie='intredeput',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBouwputType/intredeput'),
        'ontvangstput': KeuzelijstWaarde(invulwaarde='ontvangstput',
                                         label='ontvangstput',
                                         status='ingebruik',
                                         definitie='ontvangstput',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBouwputType/ontvangstput'),
        'persput': KeuzelijstWaarde(invulwaarde='persput',
                                    label='persput',
                                    status='ingebruik',
                                    definitie='persput',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBouwputType/persput')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.BetonnenConstructieElement import BetonnenConstructieElement
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KwantWrdInKubiekeMeter import KwantWrdInKubiekeMeter, KwantWrdInKubiekeMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Vlotplaat(BetonnenConstructieElement, AIMNaamObject, VlakGeometrie):
    """Een betonnen plaat met als doel de negatieve effecten bij eventuele nazakkingen van het aansluitende wegdek of spoorlijn tegen te gaan. Deze voorkomt een te abrupte en ongewenste overgang."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Vlotplaat'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kelderlandhoofd')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Landhoofd')

        self._volume = OTLAttribuut(field=KwantWrdInKubiekeMeter,
                                    naam='volume',
                                    label='volume',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Vlotplaat.volume',
                                    definition='Het volume van de vlotplaat, uitgedrukt in kubieke meter.',
                                    owner=self)

    @property
    def volume(self) -> KwantWrdInKubiekeMeterWaarden:
        """Het volume van de vlotplaat, uitgedrukt in kubieke meter."""
        return self._volume.get_waarde()

    @volume.setter
    def volume(self, value):
        self._volume.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.RHZModule import RHZModule
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.DtcAfmetingNetwerkelement import DtcAfmetingNetwerkelement, DtcAfmetingNetwerkelementWaarden
from ...Datatypes.DteIPv4Adres import DteIPv4Adres, DteIPv4AdresWaarden
from ...Datatypes.KlNetwerkMerk import KlNetwerkMerk
from ...Datatypes.KlNetwerkelemGebruik import KlNetwerkelemGebruik
from ...Datatypes.KlNetwerkelemModelnaam import KlNetwerkelemModelnaam
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Netwerkelement(RHZModule, AIMNaamObject, PuntGeometrie):
    """Toestel,onderdeel van het netwerk zoals een backbone of IP-netwerk,waarop netwerkverbindingen kunnen aangelegd worden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkelement'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LEDBord')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkkaart')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkpoort')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Rack')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#IPBackbone')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#L2AccessStructuur')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsNetwerkECC', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkelement')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SoftwareToegang')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkelement')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkpoort')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkpoort')

        self._afmeting = OTLAttribuut(field=DtcAfmetingNetwerkelement,
                                      naam='afmeting',
                                      label='afmeting',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkelement.afmeting',
                                      definition='De afmeting van een netwerkelement.',
                                      owner=self)

        self._beschrijvingFabrikant = OTLAttribuut(field=StringField,
                                                   naam='beschrijvingFabrikant',
                                                   label='beschrijving fabrikant',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkelement.beschrijvingFabrikant',
                                                   definition='Bijkomende specificaties over het apparaat of onderdeel type van de fabrikant.',
                                                   owner=self)

        self._gebruik = OTLAttribuut(field=KlNetwerkelemGebruik,
                                     naam='gebruik',
                                     label='gebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkelement.gebruik',
                                     definition='Toestel, onderdeel van het netwerk, waarop netwerkverbindingen kunnen aangelegd worden.',
                                     owner=self)

        self._ipAddressBeheer = OTLAttribuut(field=DteIPv4Adres,
                                             naam='ipAddressBeheer',
                                             label='IP address beheer',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkelement.ipAddressBeheer',
                                             definition='IP adres van het toestel.',
                                             owner=self)

        self._ipAddressMask = OTLAttribuut(field=DteIPv4Adres,
                                           naam='ipAddressMask',
                                           label='IP address mask',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkelement.ipAddressMask',
                                           definition='IP adres mask van het toestel.',
                                           owner=self)

        self._ipGateway = OTLAttribuut(field=DteIPv4Adres,
                                       naam='ipGateway',
                                       label='IP gateway',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkelement.ipGateway',
                                       definition='IP adres van gateway.',
                                       owner=self)

        self._merk = OTLAttribuut(field=KlNetwerkMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkelement.merk',
                                  definition='Merk waarmee de fabrikant het netwerkelement identificeert.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlNetwerkelemModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkelement.modelnaam',
                                       definition='Modelnaam waarmee de fabrikant dit type toestel identificeert.',
                                       owner=self)

        self._nSAPAddress = OTLAttribuut(field=StringField,
                                         naam='nSAPAddress',
                                         label='NSAP-address',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkelement.nSAPAddress',
                                         definition='Netwerkadres van deze component.',
                                         owner=self)

        self._serienummer = OTLAttribuut(field=StringField,
                                         naam='serienummer',
                                         label='serienummer',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkelement.serienummer',
                                         definition='Unieke identificatiecode van het toestel, toegekend door de fabrikant.',
                                         owner=self)

        self._softwareVersie = OTLAttribuut(field=StringField,
                                            naam='softwareVersie',
                                            label='software versie',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkelement.softwareVersie',
                                            definition='Identificatie van de softwareversie die op dit apparaat of onderdeel geladen is. Dit kan ook de firmwareversie zijn.',
                                            owner=self)

        self._telefoonnummer = OTLAttribuut(field=StringField,
                                            naam='telefoonnummer',
                                            label='telefoonnummer',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Netwerkelement.telefoonnummer',
                                            usagenote='Dit attribuut is alleen verplicht voor netwerkelementen met een eigen telefoonnummer, bv.in DSL gerelateerde installaties.',
                                            definition='Het telefoonnumer van het netwerkelement.',
                                            owner=self)

    @property
    def afmeting(self) -> DtcAfmetingNetwerkelementWaarden:
        """De afmeting van een netwerkelement."""
        return self._afmeting.get_waarde()

    @afmeting.setter
    def afmeting(self, value):
        self._afmeting.set_waarde(value, owner=self)

    @property
    def beschrijvingFabrikant(self) -> str:
        """Bijkomende specificaties over het apparaat of onderdeel type van de fabrikant."""
        return self._beschrijvingFabrikant.get_waarde()

    @beschrijvingFabrikant.setter
    def beschrijvingFabrikant(self, value):
        self._beschrijvingFabrikant.set_waarde(value, owner=self)

    @property
    def gebruik(self) -> str:
        """Toestel, onderdeel van het netwerk, waarop netwerkverbindingen kunnen aangelegd worden."""
        return self._gebruik.get_waarde()

    @gebruik.setter
    def gebruik(self, value):
        self._gebruik.set_waarde(value, owner=self)

    @property
    def ipAddressBeheer(self) -> DteIPv4AdresWaarden:
        """IP adres van het toestel."""
        return self._ipAddressBeheer.get_waarde()

    @ipAddressBeheer.setter
    def ipAddressBeheer(self, value):
        self._ipAddressBeheer.set_waarde(value, owner=self)

    @property
    def ipAddressMask(self) -> DteIPv4AdresWaarden:
        """IP adres mask van het toestel."""
        return self._ipAddressMask.get_waarde()

    @ipAddressMask.setter
    def ipAddressMask(self, value):
        self._ipAddressMask.set_waarde(value, owner=self)

    @property
    def ipGateway(self) -> DteIPv4AdresWaarden:
        """IP adres van gateway."""
        return self._ipGateway.get_waarde()

    @ipGateway.setter
    def ipGateway(self, value):
        self._ipGateway.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Merk waarmee de fabrikant het netwerkelement identificeert."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """Modelnaam waarmee de fabrikant dit type toestel identificeert."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def nSAPAddress(self) -> str:
        """Netwerkadres van deze component."""
        return self._nSAPAddress.get_waarde()

    @nSAPAddress.setter
    def nSAPAddress(self, value):
        self._nSAPAddress.set_waarde(value, owner=self)

    @property
    def serienummer(self) -> str:
        """Unieke identificatiecode van het toestel, toegekend door de fabrikant."""
        return self._serienummer.get_waarde()

    @serienummer.setter
    def serienummer(self, value):
        self._serienummer.set_waarde(value, owner=self)

    @property
    def softwareVersie(self) -> str:
        """Identificatie van de softwareversie die op dit apparaat of onderdeel geladen is. Dit kan ook de firmwareversie zijn."""
        return self._softwareVersie.get_waarde()

    @softwareVersie.setter
    def softwareVersie(self, value):
        self._softwareVersie.set_waarde(value, owner=self)

    @property
    def telefoonnummer(self) -> str:
        """Het telefoonnumer van het netwerkelement."""
        return self._telefoonnummer.get_waarde()

    @telefoonnummer.setter
    def telefoonnummer(self, value):
        self._telefoonnummer.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Naaf(AIMNaamObject, PuntGeometrie):
    """Een mechanisch element dat op een as bevestigd wordt. Het is onderdeel van een as-naaf-verbinding. Het kan gebruikt worden als verbindingsstuk om een verwisselbaar onderdeel op een as te kunnen bevestigen (zo wordt een wiel bijvoorbeeld d.m.v. een naaf op een as bevestigd). Een naaf kan ook een onderdeel van een koppeling tussen twee assen zijn. (as-naaf-naaf-as)."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Naaf'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aandrijfas')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ElastischElement')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tandwielkast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Koppeling')



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Detectielus import Detectielus
from ...Datatypes.KlVriLusFunctie import KlVriLusFunctie
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class VRIVirtueleDetectiezone(Detectielus, VlakGeometrie):
    """Een virtuele detectiezone is een draadloos alternatief voor een traditionele lus. Op basis van GPS gegevens wordt een zone of traject vastgelegd waarbinnen er (al dan niet selectieve) input dient geleverd te worden aan de verkeersregelaar. De virtuele detectiezone kan ook gebruikt worden om de detectiezones van detectiecamera's en radars te inventariseren. """

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VRIVirtueleDetectiezone'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DetectieCamera')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PTKARModem')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Radar')

        self._functie = OTLAttribuut(field=KlVriLusFunctie,
                                     naam='functie',
                                     label='functie',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VRIVirtueleDetectiezone.functie',
                                     definition='Functie van de VRI detectiezone.',
                                     owner=self)

    @property
    def functie(self) -> str:
        """Functie van de VRI detectiezone."""
        return self._functie.get_waarde()

    @functie.setter
    def functie(self, value):
        self._functie.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlRadarNiveaumetingMerk(KeuzelijstField):
    """Merknamen van de radarniveaumeting."""
    naam = 'KlRadarNiveaumetingMerk'
    label = 'Radarniveaumeting merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlRadarNiveaumetingMerk'
    definition = 'Merknamen van de radarniveaumeting.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlRadarNiveaumetingMerk'
    options = {
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlCabineLokaalKlasse(KeuzelijstField):
    """Lijst van waarden voor de classificatie van de hoogspanningscabine als lokaal volgens Synergrid."""
    naam = 'KlCabineLokaalKlasse'
    label = 'Cabine lokaal klasse'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlCabineLokaalKlasse'
    definition = 'Lijst van waarden voor de classificatie van de hoogspanningscabine als lokaal volgens Synergrid.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlCabineLokaalKlasse'
    options = {
        'BB00': KeuzelijstWaarde(invulwaarde='BB00',
                                 label='BB00',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCabineLokaalKlasse/BB00'),
        'BB05': KeuzelijstWaarde(invulwaarde='BB05',
                                 label='BB05',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCabineLokaalKlasse/BB05'),
        'BB10': KeuzelijstWaarde(invulwaarde='BB10',
                                 label='BB10',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCabineLokaalKlasse/BB10'),
        'BB20': KeuzelijstWaarde(invulwaarde='BB20',
                                 label='BB20',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCabineLokaalKlasse/BB20'),
        'BB30': KeuzelijstWaarde(invulwaarde='BB30',
                                 label='BB30',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCabineLokaalKlasse/BB30'),
        'BB40': KeuzelijstWaarde(invulwaarde='BB40',
                                 label='BB40',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCabineLokaalKlasse/BB40'),
        'BB50': KeuzelijstWaarde(invulwaarde='BB50',
                                 label='BB50',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlCabineLokaalKlasse/BB50')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




relation_uris = set()


def get_hardcoded_relation_list():
    if len(relation_uris) == 0:
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HeeftAanvullendeGeometrie')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HeeftBeheer')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HeeftBetrokkene')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HeeftNetwerkProtectie')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HeeftNetwerktoegang')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HeeftToegangsprocedure')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsAdmOnderdeelVan')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsNetwerkECC')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsSWGehostOp')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsSWOnderdeelVan')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omhult')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt')
        relation_uris.add('https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoedtAangestuurd')

    return relation_uris



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.AfmetingenDiepCBWand import AfmetingenDiepCBWand
from ...Datatypes.DtcBetonspecificaties import DtcBetonspecificaties, DtcBetonspecificatiesWaarden
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Diepwand(AfmetingenDiepCBWand):
    """Paneelsgewijs opgebouwde wand, met behulp van specifieke graafmachines in de grond gevormd. Hierbij stabiliseert een steunvloeistof (meestal een bentonietsuspensie) de sleuf."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Diepwand'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Behuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondanker')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Hoppinzuil')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SteunStandaard')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ventilatie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel')

        self._betonspecificaties = OTLAttribuut(field=DtcBetonspecificaties,
                                                naam='betonspecificaties',
                                                label='betonspecificaties',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Diepwand.betonspecificaties',
                                                definition='Specificaties van het beton.',
                                                owner=self)

        self._rekennota = OTLAttribuut(field=DtcDocument,
                                       naam='rekennota',
                                       label='rekennota',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Diepwand.rekennota',
                                       definition='Document dat berekeningen bijhoudt.',
                                       owner=self)

        self._wapeningsplan = OTLAttribuut(field=DtcDocument,
                                           naam='wapeningsplan',
                                           label='wapeningsplan',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Diepwand.wapeningsplan',
                                           definition='Plan waarin de wapening zo gedetailleerd mogelijk wordt uitgetekend (met materiaalspecificaties en de afmetingen worden weergegeven in millimeters).',
                                           owner=self)

    @property
    def betonspecificaties(self) -> DtcBetonspecificatiesWaarden:
        """Specificaties van het beton."""
        return self._betonspecificaties.get_waarde()

    @betonspecificaties.setter
    def betonspecificaties(self, value):
        self._betonspecificaties.set_waarde(value, owner=self)

    @property
    def rekennota(self) -> DtcDocumentWaarden:
        """Document dat berekeningen bijhoudt."""
        return self._rekennota.get_waarde()

    @rekennota.setter
    def rekennota(self, value):
        self._rekennota.set_waarde(value, owner=self)

    @property
    def wapeningsplan(self) -> DtcDocumentWaarden:
        """Plan waarin de wapening zo gedetailleerd mogelijk wordt uitgetekend (met materiaalspecificaties en de afmetingen worden weergegeven in millimeters)."""
        return self._wapeningsplan.get_waarde()

    @wapeningsplan.setter
    def wapeningsplan(self, value):
        self._wapeningsplan.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Onderdeel.Binnenverlichtingstoestel import Binnenverlichtingstoestel
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlNominaleSpanning import KlNominaleSpanning
from ...Datatypes.KlNoodverlichtingTypeBatterij import KlNoodverlichtingTypeBatterij
from ...Datatypes.KwantWrdInMinuut import KwantWrdInMinuut, KwantWrdInMinuutWaarden
from ...Datatypes.KwantWrdInWatt import KwantWrdInWatt, KwantWrdInWattWaarden
from otlmow_model.OtlmowModel.BaseClasses.NonNegIntegerField import NonNegIntegerField


# Generated with OTLClassCreator. To modify: extend, do not edit
class Noodverlichtingstoestel(Binnenverlichtingstoestel):
    """Een verlichtingstoestel als combinatie van de lamp en de armatuur dat ingeschakeld is in een systeem voor noodverlichting en daarom moet voldoen aan bijkomende vereisten."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Noodverlichtingstoestel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._aantalLampen = OTLAttribuut(field=NonNegIntegerField,
                                          naam='aantalLampen',
                                          label='aantal lampen',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Noodverlichtingstoestel.aantalLampen',
                                          definition='Het aantal individueel vervangbare ampen in de armatuur van toestel.',
                                          owner=self)

        self._autonomie = OTLAttribuut(field=KwantWrdInMinuut,
                                       naam='autonomie',
                                       label='autonomie',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Noodverlichtingstoestel.autonomie',
                                       definition='Geeft aan hoe lang de noodverlichting kan branden op de eigen batterij zonder voeding van een externe bron.',
                                       owner=self)

        self._getestViaAutomaat = OTLAttribuut(field=BooleanField,
                                               naam='getestViaAutomaat',
                                               label='getest via afleggen automaat',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Noodverlichtingstoestel.getestViaAutomaat',
                                               definition='Geeft aan of de werking van het noodverlichtingstoestel moet getest worden door het uitschakelen van de automaat waarlangs de netvoeding voor het toestel passeert.',
                                               owner=self)

        self._heeftAfstandsbewaking = OTLAttribuut(field=BooleanField,
                                                   naam='heeftAfstandsbewaking',
                                                   label='heeft afstandsbewaking',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Noodverlichtingstoestel.heeftAfstandsbewaking',
                                                   definition='Geeft aan of de correcte werking van het noodverlichtingstoestel al dan niet van op afstand bewaakt wordt.',
                                                   owner=self)

        self._spanning = OTLAttribuut(field=KlNominaleSpanning,
                                      naam='spanning',
                                      label='spanning',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Noodverlichtingstoestel.spanning',
                                      definition='De vereiste spanning voor (de lampen in) het verlichtingstoestel.',
                                      owner=self)

        self._typeBatterij = OTLAttribuut(field=KlNoodverlichtingTypeBatterij,
                                          naam='typeBatterij',
                                          label='type batterij',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Noodverlichtingstoestel.typeBatterij',
                                          definition='Typering van de batterij van een noodverlichtingstoestel.',
                                          owner=self)

        self._vermogen = OTLAttribuut(field=KwantWrdInWatt,
                                      naam='vermogen',
                                      label='vermogen',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Noodverlichtingstoestel.vermogen',
                                      definition='Geeft het gecombineerd vermogen in watt aan van alle lampen van het noodverlichtingstoestel.',
                                      owner=self)

    @property
    def aantalLampen(self) -> int:
        """Het aantal individueel vervangbare ampen in de armatuur van toestel."""
        return self._aantalLampen.get_waarde()

    @aantalLampen.setter
    def aantalLampen(self, value):
        self._aantalLampen.set_waarde(value, owner=self)

    @property
    def autonomie(self) -> KwantWrdInMinuutWaarden:
        """Geeft aan hoe lang de noodverlichting kan branden op de eigen batterij zonder voeding van een externe bron."""
        return self._autonomie.get_waarde()

    @autonomie.setter
    def autonomie(self, value):
        self._autonomie.set_waarde(value, owner=self)

    @property
    def getestViaAutomaat(self) -> bool:
        """Geeft aan of de werking van het noodverlichtingstoestel moet getest worden door het uitschakelen van de automaat waarlangs de netvoeding voor het toestel passeert."""
        return self._getestViaAutomaat.get_waarde()

    @getestViaAutomaat.setter
    def getestViaAutomaat(self, value):
        self._getestViaAutomaat.set_waarde(value, owner=self)

    @property
    def heeftAfstandsbewaking(self) -> bool:
        """Geeft aan of de correcte werking van het noodverlichtingstoestel al dan niet van op afstand bewaakt wordt."""
        return self._heeftAfstandsbewaking.get_waarde()

    @heeftAfstandsbewaking.setter
    def heeftAfstandsbewaking(self, value):
        self._heeftAfstandsbewaking.set_waarde(value, owner=self)

    @property
    def spanning(self) -> str:
        """De vereiste spanning voor (de lampen in) het verlichtingstoestel."""
        return self._spanning.get_waarde()

    @spanning.setter
    def spanning(self, value):
        self._spanning.set_waarde(value, owner=self)

    @property
    def typeBatterij(self) -> str:
        """Typering van de batterij van een noodverlichtingstoestel."""
        return self._typeBatterij.get_waarde()

    @typeBatterij.setter
    def typeBatterij(self, value):
        self._typeBatterij.set_waarde(value, owner=self)

    @property
    def vermogen(self) -> KwantWrdInWattWaarden:
        """Geeft het gecombineerd vermogen in watt aan van alle lampen van het noodverlichtingstoestel."""
        return self._vermogen.get_waarde()

    @vermogen.setter
    def vermogen(self, value):
        self._vermogen.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlTypeMateriaal import KlTypeMateriaal
from ...Datatypes.KlTypeVoeg import KlTypeVoeg
from ...Datatypes.KwantWrdInBar import KwantWrdInBar, KwantWrdInBarWaarden
from ...Datatypes.KwantWrdInCentimeter import KwantWrdInCentimeter, KwantWrdInCentimeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Kokervoeg(AIMObject, LijnGeometrie):
    """De kokervoeg is de naad of overgang tussen twee verschillende of gelijke materialen zodat elementen van de koker vrij kunnen bewegen ten opzichte van elkaar zonder schade te veroorzaken."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kokervoeg'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kokersectie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Koker')

        self._dilatatieCapaciteit = OTLAttribuut(field=KwantWrdInCentimeter,
                                                 naam='dilatatieCapaciteit',
                                                 label='dilatatie capaciteit',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kokervoeg.dilatatieCapaciteit',
                                                 definition='Geeft de dilatatie capaciteit van de voeg weer in centimer.',
                                                 owner=self)

        self._drukWeerstand = OTLAttribuut(field=KwantWrdInBar,
                                           naam='drukWeerstand',
                                           label='druk weerstand',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kokervoeg.drukWeerstand',
                                           definition='De druk die de voeg aankan in bar.',
                                           owner=self)

        self._etagDocument = OTLAttribuut(field=DtcDocument,
                                          naam='etagDocument',
                                          label='etag document',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kokervoeg.etagDocument',
                                          definition='De richtlijn voor uitvoering van een voeg.',
                                          owner=self)

        self._heeftVerkeerOverVoeg = OTLAttribuut(field=BooleanField,
                                                  naam='heeftVerkeerOverVoeg',
                                                  label='heeft verkeer over voeg',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kokervoeg.heeftVerkeerOverVoeg',
                                                  definition='Geeft weer of er al dan niet verkeer over de voeg passeert',
                                                  owner=self)

        self._materiaal = OTLAttribuut(field=KlTypeMateriaal,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kokervoeg.materiaal',
                                       definition='Geeft het materiaal weer dat gebruikt is voor de voegen in de koker.',
                                       owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kokervoeg.technischeFiche',
                                             definition='Technische fiche van de voeg',
                                             owner=self)

        self._typeKokervoeg = OTLAttribuut(field=KlTypeVoeg,
                                           naam='typeKokervoeg',
                                           label='type kokervoeg',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kokervoeg.typeKokervoeg',
                                           definition='Geeft het type weer van de voeg tussen de koker elementen.',
                                           owner=self)

    @property
    def dilatatieCapaciteit(self) -> KwantWrdInCentimeterWaarden:
        """Geeft de dilatatie capaciteit van de voeg weer in centimer."""
        return self._dilatatieCapaciteit.get_waarde()

    @dilatatieCapaciteit.setter
    def dilatatieCapaciteit(self, value):
        self._dilatatieCapaciteit.set_waarde(value, owner=self)

    @property
    def drukWeerstand(self) -> KwantWrdInBarWaarden:
        """De druk die de voeg aankan in bar."""
        return self._drukWeerstand.get_waarde()

    @drukWeerstand.setter
    def drukWeerstand(self, value):
        self._drukWeerstand.set_waarde(value, owner=self)

    @property
    def etagDocument(self) -> DtcDocumentWaarden:
        """De richtlijn voor uitvoering van een voeg."""
        return self._etagDocument.get_waarde()

    @etagDocument.setter
    def etagDocument(self, value):
        self._etagDocument.set_waarde(value, owner=self)

    @property
    def heeftVerkeerOverVoeg(self) -> bool:
        """Geeft weer of er al dan niet verkeer over de voeg passeert"""
        return self._heeftVerkeerOverVoeg.get_waarde()

    @heeftVerkeerOverVoeg.setter
    def heeftVerkeerOverVoeg(self, value):
        self._heeftVerkeerOverVoeg.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """Geeft het materiaal weer dat gebruikt is voor de voegen in de koker."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """Technische fiche van de voeg"""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def typeKokervoeg(self) -> str:
        """Geeft het type weer van de voeg tussen de koker elementen."""
        return self._typeKokervoeg.get_waarde()

    @typeKokervoeg.setter
    def typeKokervoeg(self, value):
        self._typeKokervoeg.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.Abstracten.Bebakening import Bebakening
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Reflectorpaal(Bebakening, PuntGeometrie):
    """Een kunststoffen paal met reflector om het verkeer te geleiden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Reflectorpaal'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wildreflector')



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from ...Datatypes.KlAfgravingSoorten import KlAfgravingSoorten
from ...Datatypes.KlGrondbestemming import KlGrondbestemming
from ...Datatypes.KwantWrdInKubiekeMeter import KwantWrdInKubiekeMeter, KwantWrdInKubiekeMeterWaarden
from ...Datatypes.KwantWrdInTon import KwantWrdInTon, KwantWrdInTonWaarden
from ...Datatypes.KwantWrdInVierkanteMeter import KwantWrdInVierkanteMeter, KwantWrdInVierkanteMeterWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Afgraving(AIMObject):
    """Wordt beschouwd als de verzameling van beheeractiviteiten die uitgevoerd kunnen worden op grond."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#Afgraving'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._bestemming = OTLAttribuut(field=KlGrondbestemming,
                                        naam='bestemming',
                                        label='bestemming',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#Afgraving.bestemming',
                                        definition='De bestemmingen of doelen van de grond.',
                                        owner=self)

        self._gewicht = OTLAttribuut(field=KwantWrdInTon,
                                     naam='gewicht',
                                     label='gewicht',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#Afgraving.gewicht',
                                     definition='Het gewicht van de grondlaag in ton.',
                                     owner=self)

        self._oppervlakte = OTLAttribuut(field=KwantWrdInVierkanteMeter,
                                         naam='oppervlakte',
                                         label='oppervlakte',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#Afgraving.oppervlakte',
                                         definition='De oppervlakte in vierkante meter van de afgraving.',
                                         owner=self)

        self._soortAfgraving = OTLAttribuut(field=KlAfgravingSoorten,
                                            naam='soortAfgraving',
                                            label='soort afgraving',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#Afgraving.soortAfgraving',
                                            definition='De specificatie van type handeling bij afgraving.',
                                            owner=self)

        self._volume = OTLAttribuut(field=KwantWrdInKubiekeMeter,
                                    naam='volume',
                                    label='volume',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#Afgraving.volume',
                                    definition='Het volume van de grondlaag in kubieke meter.',
                                    owner=self)

    @property
    def bestemming(self) -> str:
        """De bestemmingen of doelen van de grond."""
        return self._bestemming.get_waarde()

    @bestemming.setter
    def bestemming(self, value):
        self._bestemming.set_waarde(value, owner=self)

    @property
    def gewicht(self) -> KwantWrdInTonWaarden:
        """Het gewicht van de grondlaag in ton."""
        return self._gewicht.get_waarde()

    @gewicht.setter
    def gewicht(self, value):
        self._gewicht.set_waarde(value, owner=self)

    @property
    def oppervlakte(self) -> KwantWrdInVierkanteMeterWaarden:
        """De oppervlakte in vierkante meter van de afgraving."""
        return self._oppervlakte.get_waarde()

    @oppervlakte.setter
    def oppervlakte(self, value):
        self._oppervlakte.set_waarde(value, owner=self)

    @property
    def soortAfgraving(self) -> str:
        """De specificatie van type handeling bij afgraving."""
        return self._soortAfgraving.get_waarde()

    @soortAfgraving.setter
    def soortAfgraving(self, value):
        self._soortAfgraving.set_waarde(value, owner=self)

    @property
    def volume(self) -> KwantWrdInKubiekeMeterWaarden:
        """Het volume van de grondlaag in kubieke meter."""
        return self._volume.get_waarde()

    @volume.setter
    def volume(self, value):
        self._volume.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.Abstracten.ElektrischComponentennummerObject import ElektrischComponentennummerObject
from ...Classes.Abstracten.MotorVermogenskring import MotorVermogenskring
from ...Classes.Abstracten.SerienummerObject import SerienummerObject
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject


# Generated with OTLClassCreator. To modify: extend, do not edit
class Werkschakelaar(ElektrischComponentennummerObject, MotorVermogenskring, SerienummerObject, AIMNaamObject):
    """Een handbediende schakelaar die in de nabijheid van een elektromechanische installatie is aangebracht om deze gedurende onderhouds- en reparatiewerkzaamheden te kunnen uitschakelen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Werkschakelaar'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Onderstel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Pomphuis')



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.ConstructieElement import ConstructieElement
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlBewerkingsmanierMetselwerk import KlBewerkingsmanierMetselwerk
from ...Datatypes.KlMateriaalStenen import KlMateriaalStenen
from ...Datatypes.KlMetselverband import KlMetselverband
from ...Datatypes.KlTypeVoeg import KlTypeVoeg
from ...Datatypes.KwantWrdInKubiekeMeter import KwantWrdInKubiekeMeter, KwantWrdInKubiekeMeterWaarden
from ...Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Metselwerk(ConstructieElement, VlakGeometrie):
    """Bouwconstructie met stenen waarbij metselspecie het verband tussen de stenen verzorgt."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Metselwerk'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ventilatie')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructiefObject')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gewichtsmuur')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kelderlandhoofd')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kelderpijler')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Landhoofd')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Lmuur')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pijler')

        self._bewerkingsmanier = OTLAttribuut(field=KlBewerkingsmanierMetselwerk,
                                              naam='bewerkingsmanier',
                                              label='bewerkingsmanier',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Metselwerk.bewerkingsmanier',
                                              definition='De manier waarop het metselwerk bewerkt wordt.',
                                              owner=self)

        self._dikte = OTLAttribuut(field=KwantWrdInMillimeter,
                                   naam='dikte',
                                   label='dikte',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Metselwerk.dikte',
                                   definition='De (wand)dikte van het metselwerk, uitgedrukt in millimeter.',
                                   owner=self)

        self._heeftSteensnedeplan = OTLAttribuut(field=BooleanField,
                                                 naam='heeftSteensnedeplan',
                                                 label='heeft steensnedeplan',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Metselwerk.heeftSteensnedeplan',
                                                 definition='Geeft aan of het metselwerk, al dan niet, een steensnedeplan heeft (enkel van toepassing bij crinoïdenkalksteen).',
                                                 owner=self)

        self._isDragend = OTLAttribuut(field=BooleanField,
                                       naam='isDragend',
                                       label='is dragend',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Metselwerk.isDragend',
                                       definition='Geeft aan of het metselwerk dragend is, al dan niet.',
                                       owner=self)

        self._materiaalStenen = OTLAttribuut(field=KlMateriaalStenen,
                                             naam='materiaalStenen',
                                             label='materiaal stenen',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Metselwerk.materiaalStenen',
                                             definition='Het materiaal van de stenen waarmee gemetseld wordt.',
                                             owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Metselwerk.technischeFiche',
                                             definition='De technische fiche van het metselwerk (deze fiche bevat o.a. de afmetingen en de prestaties zoals druksterkte en brandreactieklasse).',
                                             owner=self)

        self._typeVoeg = OTLAttribuut(field=KlTypeVoeg,
                                      naam='typeVoeg',
                                      label='type voeg',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Metselwerk.typeVoeg',
                                      definition='Het type van de gebruikte voeg.',
                                      owner=self)

        self._verband = OTLAttribuut(field=KlMetselverband,
                                     naam='verband',
                                     label='verband',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Metselwerk.verband',
                                     definition='De rangschikking waarin stenen worden gemetseld.',
                                     owner=self)

        self._volume = OTLAttribuut(field=KwantWrdInKubiekeMeter,
                                    naam='volume',
                                    label='volume',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Metselwerk.volume',
                                    definition='Het volume van het metselwerk, uitgedrukt in kubieke meter.',
                                    owner=self)

    @property
    def bewerkingsmanier(self) -> str:
        """De manier waarop het metselwerk bewerkt wordt."""
        return self._bewerkingsmanier.get_waarde()

    @bewerkingsmanier.setter
    def bewerkingsmanier(self, value):
        self._bewerkingsmanier.set_waarde(value, owner=self)

    @property
    def dikte(self) -> KwantWrdInMillimeterWaarden:
        """De (wand)dikte van het metselwerk, uitgedrukt in millimeter."""
        return self._dikte.get_waarde()

    @dikte.setter
    def dikte(self, value):
        self._dikte.set_waarde(value, owner=self)

    @property
    def heeftSteensnedeplan(self) -> bool:
        """Geeft aan of het metselwerk, al dan niet, een steensnedeplan heeft (enkel van toepassing bij crinoïdenkalksteen)."""
        return self._heeftSteensnedeplan.get_waarde()

    @heeftSteensnedeplan.setter
    def heeftSteensnedeplan(self, value):
        self._heeftSteensnedeplan.set_waarde(value, owner=self)

    @property
    def isDragend(self) -> bool:
        """Geeft aan of het metselwerk dragend is, al dan niet."""
        return self._isDragend.get_waarde()

    @isDragend.setter
    def isDragend(self, value):
        self._isDragend.set_waarde(value, owner=self)

    @property
    def materiaalStenen(self) -> str:
        """Het materiaal van de stenen waarmee gemetseld wordt."""
        return self._materiaalStenen.get_waarde()

    @materiaalStenen.setter
    def materiaalStenen(self, value):
        self._materiaalStenen.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van het metselwerk (deze fiche bevat o.a. de afmetingen en de prestaties zoals druksterkte en brandreactieklasse)."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def typeVoeg(self) -> str:
        """Het type van de gebruikte voeg."""
        return self._typeVoeg.get_waarde()

    @typeVoeg.setter
    def typeVoeg(self, value):
        self._typeVoeg.set_waarde(value, owner=self)

    @property
    def verband(self) -> str:
        """De rangschikking waarin stenen worden gemetseld."""
        return self._verband.get_waarde()

    @verband.setter
    def verband(self, value):
        self._verband.set_waarde(value, owner=self)

    @property
    def volume(self) -> KwantWrdInKubiekeMeterWaarden:
        """Het volume van het metselwerk, uitgedrukt in kubieke meter."""
        return self._volume.get_waarde()

    @volume.setter
    def volume(self, value):
        self._volume.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlToegangspoortMerk(KeuzelijstField):
    """Lijst met merknamen voor allerlei types van toegangspoorten volgens de fabrikant"""
    naam = 'KlToegangspoortMerk'
    label = 'Toegangspoort merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlToegangspoortMerk'
    definition = 'Lijst met merknamen voor allerlei types van toegangspoorten volgens de fabrikant'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlToegangspoortMerk'
    options = {
        'bm-technics': KeuzelijstWaarde(invulwaarde='bm-technics',
                                        label='BM Technics',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangspoortMerk/bm-technics'),
        'hormann': KeuzelijstWaarde(invulwaarde='hormann',
                                    label='Hormann',
                                    status='ingebruik',
                                    definitie='HÃƒÂ¶rmann',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlToegangspoortMerk/hormann')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLumenOutput(KeuzelijstField):
    """Mogelijke waarden uitgedrukt in Lumens."""
    naam = 'KlLumenOutput'
    label = 'Lumen output'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLumenOutput'
    definition = 'Mogelijke waarden uitgedrukt in Lumens.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLumenOutput'
    options = {
        '1000': KeuzelijstWaarde(invulwaarde='1000',
                                 label='1000',
                                 status='ingebruik',
                                 definitie='1000',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/1000'),
        '10000': KeuzelijstWaarde(invulwaarde='10000',
                                  label='10000',
                                  status='ingebruik',
                                  definitie='10000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/10000'),
        '1250': KeuzelijstWaarde(invulwaarde='1250',
                                 label='1250',
                                 status='ingebruik',
                                 definitie='1250',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/1250'),
        '12500': KeuzelijstWaarde(invulwaarde='12500',
                                  label='12500',
                                  status='ingebruik',
                                  definitie='12500',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/12500'),
        '1500': KeuzelijstWaarde(invulwaarde='1500',
                                 label='1500',
                                 status='ingebruik',
                                 definitie='1500',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/1500'),
        '15000': KeuzelijstWaarde(invulwaarde='15000',
                                  label='15000',
                                  status='ingebruik',
                                  definitie='15000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/15000'),
        '1750': KeuzelijstWaarde(invulwaarde='1750',
                                 label='1750',
                                 status='ingebruik',
                                 definitie='1750',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/1750'),
        '17500': KeuzelijstWaarde(invulwaarde='17500',
                                  label='17500',
                                  status='ingebruik',
                                  definitie='17500',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/17500'),
        '2000': KeuzelijstWaarde(invulwaarde='2000',
                                 label='2000',
                                 status='ingebruik',
                                 definitie='2000',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/2000'),
        '20000': KeuzelijstWaarde(invulwaarde='20000',
                                  label='20000',
                                  status='ingebruik',
                                  definitie='20000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/20000'),
        '22500': KeuzelijstWaarde(invulwaarde='22500',
                                  label='22500',
                                  status='ingebruik',
                                  definitie='22500',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/22500'),
        '2500': KeuzelijstWaarde(invulwaarde='2500',
                                 label='2500',
                                 status='ingebruik',
                                 definitie='2500',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/2500'),
        '25000': KeuzelijstWaarde(invulwaarde='25000',
                                  label='25000',
                                  status='ingebruik',
                                  definitie='25000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/25000'),
        '3000': KeuzelijstWaarde(invulwaarde='3000',
                                 label='3000',
                                 status='ingebruik',
                                 definitie='3000',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/3000'),
        '30000': KeuzelijstWaarde(invulwaarde='30000',
                                  label='30000',
                                  status='ingebruik',
                                  definitie='30000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/30000'),
        '3500': KeuzelijstWaarde(invulwaarde='3500',
                                 label='3500',
                                 status='ingebruik',
                                 definitie='3500',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/3500'),
        '35000': KeuzelijstWaarde(invulwaarde='35000',
                                  label='35000',
                                  status='ingebruik',
                                  definitie='35000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/35000'),
        '4000': KeuzelijstWaarde(invulwaarde='4000',
                                 label='4000',
                                 status='ingebruik',
                                 definitie='4000',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/4000'),
        '40000': KeuzelijstWaarde(invulwaarde='40000',
                                  label='40000',
                                  status='ingebruik',
                                  definitie='40000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/40000'),
        '45000': KeuzelijstWaarde(invulwaarde='45000',
                                  label='45000',
                                  status='ingebruik',
                                  definitie='45000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/45000'),
        '5000': KeuzelijstWaarde(invulwaarde='5000',
                                 label='5000',
                                 status='ingebruik',
                                 definitie='5000',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/5000'),
        '50000': KeuzelijstWaarde(invulwaarde='50000',
                                  label='50000',
                                  status='ingebruik',
                                  definitie='50000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/50000'),
        '55000': KeuzelijstWaarde(invulwaarde='55000',
                                  label='55000',
                                  status='ingebruik',
                                  definitie='55000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/55000'),
        '60000': KeuzelijstWaarde(invulwaarde='60000',
                                  label='60000',
                                  status='ingebruik',
                                  definitie='60000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/60000'),
        '6250': KeuzelijstWaarde(invulwaarde='6250',
                                 label='6250',
                                 status='ingebruik',
                                 definitie='6250',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/6250'),
        '70000': KeuzelijstWaarde(invulwaarde='70000',
                                  label='70000',
                                  status='ingebruik',
                                  definitie='70000',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/70000'),
        '7500': KeuzelijstWaarde(invulwaarde='7500',
                                 label='7500',
                                 status='ingebruik',
                                 definitie='7500',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/7500'),
        '8750': KeuzelijstWaarde(invulwaarde='8750',
                                 label='8750',
                                 status='ingebruik',
                                 definitie='8750',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLumenOutput/8750')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from ...Datatypes.KlBouwmethode import KlBouwmethode
from ...Datatypes.KlGebruikersType import KlGebruikersType
from ...Datatypes.KlTypeOndergrond import KlTypeOndergrond
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Kokersectie(AIMObject, VlakGeometrie):
    """Een kokersectie is een deel van een serie elementen waaruit een kokercomplex is opgebouwd."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kokersectie'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AanhorigheidKoker')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brugdekvoeg')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kokervoeg')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wegdekvoeg')
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kokercomplex')

        self._bouwmethode = OTLAttribuut(field=KlBouwmethode,
                                         naam='bouwmethode',
                                         label='bouwmethode',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kokersectie.bouwmethode',
                                         definition='Geeft een keuzelijst dat aangeeft hoe het koker element gebouwd en op zijn plek gezet is.',
                                         owner=self)

        self._gebruikersOnderSectie = OTLAttribuut(field=KlGebruikersType,
                                                   naam='gebruikersOnderSectie',
                                                   label='gebruikers onder sectie',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kokersectie.gebruikersOnderSectie',
                                                   definition='Geeft aan welk hoofdzakelijk type gebruikers er zich onder de sectie begeven.',
                                                   owner=self)

        self._gebruikersOpSectie = OTLAttribuut(field=KlGebruikersType,
                                                naam='gebruikersOpSectie',
                                                label='gebruikers op sectie',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kokersectie.gebruikersOpSectie',
                                                definition='Geeft een keuzelijst van gebruikers dat kunnen voorkomen op de desbetreffende sectie.',
                                                owner=self)

        self._typeOndergrond = OTLAttribuut(field=KlTypeOndergrond,
                                            naam='typeOndergrond',
                                            label='type ondergrond',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kokersectie.typeOndergrond',
                                            definition='Geeft aan welke ondergrond er de desbetreffende sectie zit.',
                                            owner=self)

    @property
    def bouwmethode(self) -> str:
        """Geeft een keuzelijst dat aangeeft hoe het koker element gebouwd en op zijn plek gezet is."""
        return self._bouwmethode.get_waarde()

    @bouwmethode.setter
    def bouwmethode(self, value):
        self._bouwmethode.set_waarde(value, owner=self)

    @property
    def gebruikersOnderSectie(self) -> str:
        """Geeft aan welk hoofdzakelijk type gebruikers er zich onder de sectie begeven."""
        return self._gebruikersOnderSectie.get_waarde()

    @gebruikersOnderSectie.setter
    def gebruikersOnderSectie(self, value):
        self._gebruikersOnderSectie.set_waarde(value, owner=self)

    @property
    def gebruikersOpSectie(self) -> str:
        """Geeft een keuzelijst van gebruikers dat kunnen voorkomen op de desbetreffende sectie."""
        return self._gebruikersOpSectie.get_waarde()

    @gebruikersOpSectie.setter
    def gebruikersOpSectie(self, value):
        self._gebruikersOpSectie.set_waarde(value, owner=self)

    @property
    def typeOndergrond(self) -> str:
        """Geeft aan welke ondergrond er de desbetreffende sectie zit."""
        return self._typeOndergrond.get_waarde()

    @typeOndergrond.setter
    def typeOndergrond(self, value):
        self._typeOndergrond.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.VRModuleZFirmware import VRModuleZFirmware
from ...Datatypes.KlVRBatterijCUMerk import KlVRBatterijCUMerk
from ...Datatypes.KlVRBatterijCUModelnaam import KlVRBatterijCUModelnaam


# Generated with OTLClassCreator. To modify: extend, do not edit
class VRBatterijICU(VRModuleZFirmware):
    """Batterij die zorgt dat de primaire melding "spanning afwezig", in het geval van een spanningsuitval, nog kan doorgestuurd worden naar het afstandsbewakingssysteem."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VRBatterijICU'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._merk = OTLAttribuut(field=KlVRBatterijCUMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VRBatterijICU.merk',
                                  definition='De merknaam van de VR-batterij ICU.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlVRBatterijCUModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VRBatterijICU.modelnaam',
                                       definition='De modelnaam van de VR-batterij ICU.',
                                       owner=self)

    @property
    def merk(self) -> str:
        """De merknaam van de VR-batterij ICU."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de VR-batterij ICU."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLEACObstakelbeveiligerType(KeuzelijstField):
    """De verschillende types van obstakelbeveiliger."""
    naam = 'KlLEACObstakelbeveiligerType'
    label = 'Obstakelbeveiliger type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLEACObstakelbeveiligerType'
    definition = 'De verschillende types van obstakelbeveiliger.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLEACObstakelbeveiligerType'
    options = {
        'afstoppend-(NR)': KeuzelijstWaarde(invulwaarde='afstoppend-(NR)',
                                            label='afstoppend (NR)',
                                            status='ingebruik',
                                            definitie='Obstakelbeveiliger brengt het voertuig tot stilstand maar zijn niet getest op zijdelingse aanrijdingen',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEACObstakelbeveiligerType/afstoppend-(NR)'),
        'geleidend-(R)': KeuzelijstWaarde(invulwaarde='geleidend-(R)',
                                          label='geleidend (R)',
                                          status='ingebruik',
                                          definitie='Obstakelbeveiliger brengt het voertuig niet tot stilstand maar terug in de juiste richting',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEACObstakelbeveiligerType/geleidend-(R)')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Proef import Proef
from otlmow_model.OtlmowModel.BaseClasses.FloatOrDecimalField import FloatOrDecimalField
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class ProefZichtbaarheidBijNachtRegenweer(Proef, PuntGeometrie, LijnGeometrie, VlakGeometrie):
    """Bepaling van het retroreflecterend vermogen van een markering bij nacht bij nat weer (tijdens regenbui)."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefZichtbaarheidBijNachtRegenweer'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Markering')

        self._retrotreflectiecoëfficiënt = OTLAttribuut(field=FloatOrDecimalField,
                                                        naam='retrotreflectiecoëfficiënt',
                                                        label='retrotreflectiecoëfficiënt',
                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefZichtbaarheidBijNachtRegenweer.retrotreflectiecoëfficiënt',
                                                        usagenote='uitgedrukt in mcd. m-2.lux-1',
                                                        definition='De maat voor het retroreflecterend vermogen van een markering bij nacht bij nat weer (tijdens regenbui).',
                                                        owner=self)

    @property
    def retrotreflectiecoëfficiënt(self) -> float:
        """De maat voor het retroreflecterend vermogen van een markering bij nacht bij nat weer (tijdens regenbui)."""
        return self._retrotreflectiecoëfficiënt.get_waarde()

    @retrotreflectiecoëfficiënt.setter
    def retrotreflectiecoëfficiënt(self, value):
        self._retrotreflectiecoëfficiënt.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.PTModuleMetFirmware import PTModuleMetFirmware
from ...Datatypes.KlPtKARModemProtocol import KlPtKARModemProtocol


# Generated with OTLClassCreator. To modify: extend, do not edit
class PTKARModem(PTModuleMetFirmware):
    """Modem die KAR signalen, korte afstands radiosignalen, kan ontvangen van de KAR-module die geïnstalleerd is op het openbaar vervoer voertuig. Het voertuig meldt zich zo via virtuele lussen, gedefinieerd op basis van GPS- positie, aan bij de PT regelaar."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PTKARModem'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VRIVirtueleDetectiezone')

        self._protocolOVVoertuig = OTLAttribuut(field=KlPtKARModemProtocol,
                                                naam='protocolOVVoertuig',
                                                label='protocol OV-voertuig',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PTKARModem.protocolOVVoertuig',
                                                definition='Beschrijft het protocol dat gebruikt wordt om te communiceren met een OV-voertuig.',
                                                owner=self)

        self._protocolRegelaar = OTLAttribuut(field=KlPtKARModemProtocol,
                                              naam='protocolRegelaar',
                                              label='protocol regelaar',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PTKARModem.protocolRegelaar',
                                              definition='Beschrijft het protocol dat gebruikt wordt om te communiceren met een regelaar.',
                                              owner=self)

    @property
    def protocolOVVoertuig(self) -> str:
        """Beschrijft het protocol dat gebruikt wordt om te communiceren met een OV-voertuig."""
        return self._protocolOVVoertuig.get_waarde()

    @protocolOVVoertuig.setter
    def protocolOVVoertuig(self, value):
        self._protocolOVVoertuig.set_waarde(value, owner=self)

    @property
    def protocolRegelaar(self) -> str:
        """Beschrijft het protocol dat gebruikt wordt om te communiceren met een regelaar."""
        return self._protocolRegelaar.get_waarde()

    @protocolRegelaar.setter
    def protocolRegelaar(self, value):
        self._protocolRegelaar.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlRoosterIndeling(KeuzelijstField):
    """Deze keuzelijst geeft aan hoe het rooster ingedeeld is: met zijdelingse opvang of dat er sprake is van een 1-delig of 2-delig rooster."""
    naam = 'KlRoosterIndeling'
    label = 'Rooster indeling'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlRoosterIndeling'
    definition = 'Deze keuzelijst geeft aan hoe het rooster ingedeeld is: met zijdelingse opvang of dat er sprake is van een 1-delig of 2-delig rooster.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlRoosterIndeling'
    options = {
        '1-delig': KeuzelijstWaarde(invulwaarde='1-delig',
                                    label='1-delig',
                                    status='ingebruik',
                                    definitie='1-delig',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlRoosterIndeling/1-delig'),
        '2-delig': KeuzelijstWaarde(invulwaarde='2-delig',
                                    label='2-delig',
                                    status='ingebruik',
                                    definitie='2-delig',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlRoosterIndeling/2-delig'),
        'zijdelingse-opvang': KeuzelijstWaarde(invulwaarde='zijdelingse-opvang',
                                               label='zijdelingse opvang',
                                               status='ingebruik',
                                               definitie='zijdelingse opvang',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlRoosterIndeling/zijdelingse-opvang')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

